import os

from pathlib import Path
from xonsh import dirstack

_file = Path(__xonsh__.env.get('XDG_CACHE_HOME', '~/.cache')).expanduser() / 'xontrib-back2dir' / 'latest.path'


@events.on_post_init
def on_post_init(**_):
    if __xonsh__.env["PWD"] == __xonsh__.env["HOME"] and _file.exists():
        __xonsh__.subproc_captured_stdout(['cd', _file.read_text()])

@events.on_chdir
def autojump_add_to_database(olddir, newdir, **kwargs):
    if not _file.parent.exists():
        os.mkdir(_file.parent)
    with open(_file, 'w') as f:
        print(newdir, end='', file=f)



#!/usr/bin/env python
import setuptools

try:
    with open('README.md', 'r', encoding='utf-8') as fh:
        long_description = fh.read()
except (IOError, OSError):
    long_description = ''

setuptools.setup(
    name='xontrib-back2dir',
    version='0.0.9',
    license='MIT',
    author='anki-code',
    author_email='anki-code@no.no',
    description="Back to directory.",
    long_description=long_description,
    long_description_content_type='text/markdown',
    python_requires='>=3.6',
    packages=['xontrib'],
    package_dir={'xontrib': 'xontrib'},
    package_data={'xontrib': ['*.py']},
    platforms='any',
    url='https://github.com/anki-code/xontrib-back2dir',
    project_urls={
        "Documentation": "https://github.com/anki-code/xontrib-back2dir/blob/master/README.md",
        "Code": "https://github.com/anki-code/xontrib-back2dir",
        "Issue tracker": "https://github.com/anki-code/xontrib-back2dir/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: System :: Shells",
        "Topic :: System :: System Shells",
        "Topic :: Terminals",
    ]
)
